@@ -1,7 +1,7 @@
-(def tk-version "1.1.0")
-(def tk-jetty-version "1.3.0")
-(def ks-version "1.0.0")
-(def ps-version "1.0.8")
+(def tk-version "1.1.1")
+(def tk-jetty-version "1.3.1")
+(def ks-version "1.1.0")
+(def ps-version "1.1.0")
 
 (defn deploy-info
   [url]
@@ -17,27 +17,32 @@
                  [puppetlabs/trapperkeeper ~tk-version]
                  [puppetlabs/kitchensink ~ks-version]
                  [puppetlabs/ssl-utils "0.8.0"]
-                 [puppetlabs/http-client "0.4.3"]
-                 [org.jruby/jruby-core "1.7.19"
+                 [puppetlabs/http-client "0.4.4"]
+                 [org.jruby/jruby-core "1.7.20"
                   :exclusions [com.github.jnr/jffi com.github.jnr/jnr-x86asm]]
-                 [com.github.jnr/jffi "1.2.7"]
-                 [com.github.jnr/jffi "1.2.7" :classifier "native"]
+                 ;; jffi and jnr-x86asm are explicit dependencies because,
+                 ;; in JRuby's poms, they are defined using version ranges,
+                 ;; and :pedantic? :abort won't tolerate this.
+                 [com.github.jnr/jffi "1.2.9"]
+                 [com.github.jnr/jffi "1.2.9" :classifier "native"]
                  [com.github.jnr/jnr-x86asm "1.0.2"]
                  ;; NOTE: jruby-stdlib packages some unexpected things inside
                  ;; of its jar; please read the detailed notes above the
                  ;; 'uberjar-exclusions' example toward the end of this file.
-                 [org.jruby/jruby-stdlib "1.7.19"]
-                 [clj-time "0.5.1" :exclusions [joda-time]]
-                 [compojure "1.1.8" :exclusions [org.clojure/tools.macro]]
+                 [org.jruby/jruby-stdlib "1.7.20"]
+                 [org.clojure/data.json "0.2.3"]
+                 [org.clojure/tools.macro "0.1.5"]
+                 [joda-time "2.5"]
+                 [clj-time "0.6.0"]
                  [liberator "0.12.0"]
+                 [puppetlabs/comidi "0.1.1"]
                  [me.raynes/fs "1.4.5"]
-                 [prismatic/schema "0.2.2"]
+                 [prismatic/schema "0.4.0"]
                  [commons-lang "2.6"]
                  [commons-io "2.4"]
                  [commons-codec "1.9"]
                  [clj-yaml "0.4.0" :exclusions [org.yaml/snakeyaml]]
                  [slingshot "0.10.3"]
-                 [ring/ring-codec "1.0.0"]
                  [cheshire "5.3.1"]
                  [trptcolin/versioneer "0.1.0"]]
 
@@ -86,7 +91,7 @@
              :ezbake {:dependencies ^:replace [[puppetlabs/puppetserver ~ps-version]
                                                [puppetlabs/trapperkeeper-webserver-jetty9 ~tk-jetty-version]
                                                [org.clojure/tools.nrepl "0.2.3"]]
-                      :plugins [[puppetlabs/lein-ezbake "0.2.6"]]
+                      :plugins [[puppetlabs/lein-ezbake "0.2.10"]]
                       :name "puppetserver"}
 
              :uberjar {:aot [puppetlabs.trapperkeeper.main]}
