@@ -9,7 +9,9 @@
     (.setEnvironment
       (hash-map
         "GEM_HOME" (get-in config [:jruby-puppet :gem-home])
-        "JARS_NO_REQUIRE" "true"))
+        "JARS_NO_REQUIRE" "true"
+        "JARS_REQUIRE" "false"))
+    (.runScriptlet "require 'jar-dependencies'")
     (.runScriptlet "load 'META-INF/jruby.home/bin/gem'")))
 
 (defn -main
