@@ -1,18 +1,19 @@
 (ns puppetlabs.services.ca.certificate-authority-core
-  (:import  [java.io InputStream])
+  (:import [java.io InputStream]
+           (clojure.lang IFn))
   (:require [puppetlabs.puppetserver.certificate-authority :as ca]
             [puppetlabs.puppetserver.ringutils :as ringutils]
             [puppetlabs.puppetserver.liberator-utils :as utils]
+            [puppetlabs.comidi :as comidi :refer [GET ANY PUT]]
             [slingshot.slingshot :as sling]
             [clojure.tools.logging :as log]
             [clojure.java.io :as io]
             [clojure.string :as string]
             [schema.core :as schema]
             [cheshire.core :as cheshire]
-            [compojure.core :as compojure :refer [GET ANY PUT]]
             [liberator.core :refer [defresource]]
+            ;[liberator.dev :as liberator-dev]
             [liberator.representation :as representation]
-            [liberator.dev :as liberator-dev]
             [ring.util.response :as rr]))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -53,7 +54,7 @@
       (rr/content-type "text/plain")))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;; Compojure app
+;;; Web app
 
 (defn try-to-parse
   [body]
@@ -236,40 +237,28 @@
       (ca/get-certificate-statuses settings)
       (as-json-or-pson context))))
 
-(schema/defn routes
+(schema/defn ^:always-validate web-routes :- comidi/BidiRoute
   [ca-settings :- ca/CaSettings]
-  (compojure/context "/:environment" [environment]
-    (compojure/routes
-      (ANY "/certificate_status/:subject" [subject]
-        (certificate-status subject ca-settings))
-      (ANY "/certificate_statuses/:ignored-but-required" [do-not-use]
-        (certificate-statuses ca-settings)))
-      (GET "/certificate/:subject" [subject]
-        (handle-get-certificate subject ca-settings))
-      (compojure/context "/certificate_request/:subject" [subject]
-        (GET "/" []
-          (handle-get-certificate-request subject ca-settings))
-        (PUT "/" {body :body}
-          (handle-put-certificate-request! subject body ca-settings)))
-      (GET "/certificate_revocation_list/:ignored-node-name" []
-        (handle-get-certificate-revocation-list ca-settings))))
-
-(defn wrap-with-puppet-version-header
-  "Function that returns a middleware that adds an
-  X-Puppet-Version header to the response."
-  [handler version]
-  (fn [request]
-    (let [response (handler request)]
-      ; Our compojure app returns nil responses sometimes.
-      ; In that case, don't add the header.
-      (when response
-        (rr/header response "X-Puppet-Version" version)))))
+  (comidi/context ["/" :environment]
+    (ANY ["/certificate_status/" :subject] [subject]
+         (certificate-status subject ca-settings))
+    (ANY ["/certificate_statuses/" :ignored-but-required] []
+         (certificate-statuses ca-settings))
+    (GET ["/certificate/" :subject] [subject]
+         (handle-get-certificate subject ca-settings))
+    (comidi/context ["/certificate_request/" :subject]
+      (GET [""] [subject]
+           (handle-get-certificate-request subject ca-settings))
+      (PUT [""] [subject :as {body :body}]
+           (handle-put-certificate-request! subject body ca-settings)))
+    (GET ["/certificate_revocation_list/" :ignored-node-name] []
+         (handle-get-certificate-revocation-list ca-settings))))
 
 (schema/defn ^:always-validate
-  build-ring-handler
-  [ca-settings :- ca/CaSettings
+  wrap-middleware :- IFn
+  [handler :- IFn
    puppet-version :- schema/Str]
-  (-> (routes ca-settings)
-      ;(liberator-dev/wrap-trace :header)           ; very useful for debugging!
-      (wrap-with-puppet-version-header puppet-version)
-      (ringutils/wrap-response-logging)))
+  (-> handler
+    ;(liberator-dev/wrap-trace :header)           ; very useful for debugging!
+    (ringutils/wrap-with-puppet-version-header puppet-version)
+    (ringutils/wrap-response-logging)))
\ No newline at end of file
